#!/bin/sh

echo "AURES Technologies"
echo "AURES Technologies ESCP CUPS DRIVER Mac OS Installer"
echo "---------------------------------------"
echo ""
echo "Models included:"

echo "         AURES SMP 58"
echo "         AURES SLP 580"
echo ""

ROOT_UID=0

if [ "$UID" -ne "$ROOT_UID" ]
then
    echo "This script requires root user access..."
    echo "Re-run as root user..."
    exit 1
fi

if [ ! -z $DESTDIR ]
then
    echo "DESTDIR set to $DESTDIR"
    echo ""
fi

SERVERROOT=$(grep '^ServerRoot' /etc/cups/cupsd.conf | awk '{print $2}')

if [ -z $FILTERDIR ] || [ -z $PPDDIR ]
then
    echo "Searching for ServerRoot, ServerBin, and DataDir tags in /etc/cups/cupsd.conf"
    echo ""

    if [ -z $FILTERDIR ]
    then
        SERVERBIN=$(grep '^ServerBin' /etc/cups/cupsd.conf | awk '{print $2}')

        if [ -z $SERVERBIN ]
        then
            echo "ServerBin tag not present in cupsd.conf - using default"
            FILTERDIR=usr/libexec/cups/filter
        elif [ ${SERVERBIN:0:1} = "/" ]
        then
            echo "ServerBin tag is present as an absolute path"
            FILTERDIR=$SERVERBIN/filter
        else
            echo "ServerBin tag is present as a relative path - appending to ServerRoot"
            FILTERDIR=$SERVERROOT/$SERVERBIN/filter
        fi
    fi

    echo ""

    if [ -z $PPDDIR ]
    then
        DATADIR=$(grep '^DataDir' /etc/cups/cupsd.conf | awk '{print $2}')

        if [ -z $DATADIR ]
        then
            echo "DataDir tag not present in cupsd.conf - using default"
            PPDDIR=/usr/share/cups/model/AURES
        elif [ ${DATADIR:0:1} = "/" ]
        then
            echo "DataDir tag is present as an absolute path"
            PPDDIR=$DATADIR/model/AURES
        else
            echo "DataDir tag is present as a relative path - appending to ServerRoot"
            PPDDIR=$SERVERROOT/$DATADIR/model/AURES
        fi
    fi

    echo ""

    echo "ServerRoot = $SERVERROOT"
    echo "ServerBin  = $SERVERBIN"
    echo "DataDir    = $DATADIR"
    echo ""
fi

echo "Copying rastertosmp58 filter to $DESTDIR/$FILTERDIR"
sudo mkdir -p $DESTDIR/$FILTERDIR
sudo chmod +x rastertosmp58
sudo cp rastertosmp58 $DESTDIR/$FILTERDIR
echo ""

echo "Copying rastertoslp580 filter to $DESTDIR/$FILTERDIR"
sudo mkdir -p $DESTDIR/$FILTERDIR
sudo chmod +x rastertoslp580
sudo cp rastertoslp580 $DESTDIR/$FILTERDIR
echo ""

echo "Copying model ppd files to $DESTDIR/$PPDDIR"
sudo mkdir -p $DESTDIR/$PPDDIR
sudo cp *.gz $DESTDIR/$PPDDIR
echo ""


if [ -e /System/Library/LaunchDaemons/printer.plist ]
then
	echo "Restarting CUPS"
	sudo killall cupsd
	sudo cupsd
	sudo launchctl  unload -w /System/Library/LaunchDaemons/printer.plist
	sudo launchctl load -w /System/Library/LaunchDaemons/printer.plist
	echo ""
fi

if [ -e /System/Library/LaunchDaemons/org.cups.cupsd.plist ]
then
	echo "Restarting CUPS"
	sudo launchctl  unload /System/Library/LaunchDaemons/org.cups.cupsd.plist
	sudo launchctl load /System/Library/LaunchDaemons/org.cups.cupsd.plist
	echo ""
fi


echo "Install Complete"
echo "Add printer queue using Printing Manager, or"
echo "Add printer queue using OS tool, http://localhost:631, or http://127.0.0.1:631"
echo ""
